@@ -52,6 +52,10 @@ func ShowFlags() []cli.Flag {
 			Aliases: []string{"n"},
 			Usage:   "Do not parse the output.",
 		},
+		&cli.BoolFlag{
+			Name:  "nosync",
+			Usage: "Disable auto-sync",
+		},
 		&cli.StringFlag{
 			Name:  "chars",
 			Usage: "Print specific characters from the secret",
@@ -706,6 +710,11 @@ func (s *Action) GetCommands() []*cli.Command {
 					Aliases: []string{"o"},
 					Usage:   "Only display the token",
 				},
+				&cli.BoolFlag{
+					Name:    "snip",
+					Aliases: []string{"s"},
+					Usage:   "Scan screen content to insert a OTP QR code into provided entry",
+				},
 			},
 		},
 		{
