@@ -398,7 +398,7 @@ func (s *Store) UpdateExportedPublicKeys(ctx context.Context, rs []string) (bool
 	}
 
 	if exported && ctxutil.IsGitCommit(ctx) {
-		if err := s.storage.Commit(ctx, fmt.Sprintf("Updated exported Public Keys")); err != nil {
+		if err := s.storage.Commit(ctx, "Updated exported Public Keys"); err != nil {
 			switch {
 			case errors.Is(err, store.ErrGitNothingToCommit):
 				debug.Log("nothing to commit: %s", err)
